# RegexRiot

[![unit-test-script](https://github.com/RK22000/regex-riot-python/actions/workflows/test.yml/badge.svg)](https://github.com/RK22000/regex-riot-python/actions/workflows/test.yml) [![Render Sphinx docs](https://github.com/RK22000/regex-riot-python/actions/workflows/docsite.yml/badge.svg)](https://rk22000.github.io/regex-riot-python/)

[![Jupyter Lite](https://jupyterlite.readthedocs.io/en/latest/_static/badge.svg)](https://rk22000.github.io/regex-riot-python/demo/repl/?toolbar=1&kernel=python&code=from%20RegexRiot.riot%20import%20*%0Aone_or_more(DIGIT).then(DOT).then(one_or_more(DIGIT))) Mess around with it in a repl.

[![Jupyter Lite](https://jupyterlite.readthedocs.io/en/latest/_static/badge.svg)](https://rk22000.github.io/regex-riot-python/demo/notebooks/?path=try_it_out.ipynb) See its effectiveness against a few regex exercises.


[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/RK22000/regex-riot-python/HEAD?labpath=src%2Ftry_it_out.ipynb)
Try it out in binder if lite isn't working.

Check out the documentation [here](https://rk22000.github.io/regex-riot-python/)